require 'android-xml'


describe 'Android resource files' do

  before do
    AndroidXml.reset
    AndroidXml.setup_defaults
  end

  it 'should generate a sensible style.xml file' do
    xml = AndroidXml.file('res/values/style.xml') do
      resources do
        style(name: 'CodeFont', parent: '@android:style/TextAppearance.Medium') do
          item(name: "android:layout_width") { 'fill_parent' }
          item(name: "android:layout_height") { 'wrap_content' }
          item(name: "android:textColor") { '#00FF00' }
          item(name: "android:typeface") { 'monospace' }
        end
      end
    end

    expect(xml.to_s).to eql <<-XML
<!-- Do not edit this file. It was generated by AndroidXml. -->
<resources>
    <style name="CodeFont"
           parent="@android:style/TextAppearance.Medium">
        <item name="android:layout_width">fill_parent</item>
        <item name="android:layout_height">wrap_content</item>
        <item name="android:textColor">#00FF00</item>
        <item name="android:typeface">monospace</item>
    </style>
</resources>
XML
  end

  it 'should generate a sensible strings.xml file' do
    xml = AndroidXml.file('res/values/strings.xml') do
      resources do
        string(name: 'app_name') { 'Harroo' }
        string(name: 'hello') { 'Well, Harroo!' }
        string(name: 'portrait') { 'portrait' }
        string(name: 'landscape') { 'landscape' }
        string(name: 'button_send') { 'Send' }
        string(name: 'action_search') { 'Search' }
        string(name: 'action_settings') { 'Settings' }
        string(name: 'title_activity_main') { 'MainActivity' }
      end
    end

    expect(xml.to_s).to eql <<-XML
<!-- Do not edit this file. It was generated by AndroidXml. -->
<resources>
    <string name="app_name">Harroo</string>
    <string name="hello">Well, Harroo!</string>
    <string name="portrait">portrait</string>
    <string name="landscape">landscape</string>
    <string name="button_send">Send</string>
    <string name="action_search">Search</string>
    <string name="action_settings">Settings</string>
    <string name="title_activity_main">MainActivity</string>
</resources>
XML
  end

  it 'should generate a sensible color.xml file' do
    xml = AndroidXml.file('res/values/color.xml') do
      resources do
        color(name: 'foo') { '#f00' }
      end
    end

    expect(xml.to_s).to eql <<-XML
<!-- Do not edit this file. It was generated by AndroidXml. -->
<resources>
    <color name="foo">#f00</color>
</resources>
XML
  end

end
