require 'android-xml'


describe 'tag attributes' do

  before do
    AndroidXml.reset
  end

  it 'should generate <any-tag tag="value" />' do
    xml = AndroidXml.file('tmp/test.xml') do
      any_tag(tag: "value")
    end

    expect(xml.to_s).to match %r{<any-tag android:tag="value" />}
  end

  it 'should generate <any-tag tag="value-with-quotes" />' do
    xml = AndroidXml.file('tmp/test.xml') do
      any_tag(tag: %q{value-"'<>&-with-quoted})
    end

    expect(xml.to_s).to match %r{<any-tag android:tag="value-&quot;&apos;&lt;&gt;&amp;-with-quoted" />}
  end

  it 'should generate prefixed attributes when using a hash' do
    xml = AndroidXml.file('tmp/test.xml') do
      any_tag(layout: {
          width: 'match_parent',
          height: 'match_parent',
          padding: 6.dp,
        })
    end

    expect(xml.to_s).to eql <<-XML
<!-- Do not edit this file. It was generated by AndroidXml. -->
<any-tag android:layout_width="match_parent"
         android:layout_height="match_parent"
         android:layout_padding="6dp" />
XML
  end

  it 'should properly clone a tag with nested attrs' do
    any_tag = AndroidXml.any_tag(layout: {
      width: 'match_parent',
      height: 'match_parent',
      padding: 6.dp,
    })

    xml = AndroidXml.file('tmp/test.xml') do
      resources do
        include any_tag.clone
        include any_tag.clone layout_height: 'wrap_content'
      end
    end

    expect(any_tag.to_s).to eql <<-XML
<any-tag android:layout_width="match_parent"
         android:layout_height="match_parent"
         android:layout_padding="6dp" />
XML
    expect(any_tag.clone(layout_height: 'wrap_content').to_s).to eql <<-XML
<any-tag android:layout_width="match_parent"
         android:layout_height="wrap_content"
         android:layout_padding="6dp" />
XML

    expect(xml.to_s).to eql <<-XML
<!-- Do not edit this file. It was generated by AndroidXml. -->
<resources>
    <any-tag android:layout_width="match_parent"
             android:layout_height="match_parent"
             android:layout_padding="6dp" />
    <any-tag android:layout_width="match_parent"
             android:layout_height="wrap_content"
             android:layout_padding="6dp" />
</resources>
XML
  end

end
